/*
 * JDU: Disk Usage
 * 
 * Copyright (c) 2001-2005 Jason Pratt
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package org.jasonpratt.jdu;

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import javax.swing.border.*;

/**
 * @author Jason Pratt
 */
public class AboutDialog extends JDialog {
	private static final long serialVersionUID = 570421689766010894L;
	protected java.awt.Color textColor = new java.awt.Color( 255, 255, 153  );
	protected java.awt.event.MouseAdapter urlMouseListener = new java.awt.event.MouseAdapter() {
		public void mouseReleased( java.awt.event.MouseEvent ev ) {
			int x = ev.getX();
			int y = ev.getY();
			java.awt.Dimension size = ev.getComponent().getSize();
			if( (x > 0) && (y > 0) && (x < size.width) && (y < size.height) ) {
				try {
					JDUFrame.openURL( "http://jasonpratt.org/software/jdu/" );
				} catch( Throwable t ) {
					System.err.println( "Ooops. Couldn't load the URL;  " + t.getMessage() );
				}
			}
		}
	};

	public AboutDialog( java.awt.Frame owner ) {
		super( owner );
		jbInit();
		guiInit();
	}

	private void guiInit() {
		titleLabel.setForeground( textColor );
		copyrightLabel.setForeground( textColor );
		versionLabel.setForeground( textColor );
		infoLabel.setForeground( textColor );

		urlLabel.setCursor( java.awt.Cursor.getPredefinedCursor( java.awt.Cursor.HAND_CURSOR ) );
		urlLabel.addMouseListener( urlMouseListener );
		versionLabel.setText( "version " + JDUFrame.version );

		setSize( 377, 233 );

		setDefaultCloseOperation( javax.swing.JDialog.HIDE_ON_CLOSE );
	}

	/////////////
	// Callbacks
	/////////////

	void okayButton_actionPerformed(ActionEvent e) {
		setVisible( false );
	}

	//////////////////
	// Autogenerated
	//////////////////

	GridBagLayout gridBagLayout1 = new GridBagLayout();
	JLabel infoLabel = new JLabel();
	JPanel titlePanel = new JPanel();
	GridBagLayout gridBagLayout2 = new GridBagLayout();
	JLabel titleLabel = new JLabel();
	JLabel copyrightLabel = new JLabel();
	JButton okayButton = new JButton();
	JLabel versionLabel = new JLabel();
	Border border1;
	Border border2;
	JPanel jPanel1 = new JPanel();
	JLabel urlLabel = new JLabel();

	private void jbInit() {
		border1 = BorderFactory.createEmptyBorder( 2, 8, 2, 8 );
		border2 = BorderFactory.createCompoundBorder(BorderFactory.createRaisedBevelBorder(),BorderFactory.createEmptyBorder(2,8,2,8));
		copyrightLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
		copyrightLabel.setText("\u00A9 2001, Jason Pratt");
		titlePanel.setOpaque(false);
		titleLabel.setText("JDU: Disk Usage");
		titleLabel.setFont(new java.awt.Font("SansSerif", 1, 22));
		this.getContentPane().setBackground( Color.black );
		this.setModal(true);
		this.setTitle("About JDU");
		this.getContentPane().setLayout(gridBagLayout1);
		infoLabel.setFont(new java.awt.Font("Serif", 1, 14));
		infoLabel.setText("For more information about JDU, visit:");
		titlePanel.setLayout(gridBagLayout2);
		okayButton.setBackground(new Color(255, 255, 200));
		okayButton.setBorder(border2);
		okayButton.setFocusPainted(false);
		okayButton.setText("Okay");
		okayButton.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(ActionEvent e) {
				okayButton_actionPerformed(e);
			}
		});
		versionLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
		versionLabel.setText("version");
		jPanel1.setBackground(new Color(119, 119, 119));
		jPanel1.setMinimumSize(new Dimension(0, 0));
		jPanel1.setPreferredSize(new Dimension(0, 0));
		urlLabel.setFont(new java.awt.Font("Serif", 1, 14));
		urlLabel.setText("<html><b><u><font color=#99CCFF>http://jasonpratt.org/software/jdu/</font></u></b></html>");
		this.getContentPane().add(infoLabel,                  new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0
			,GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(20, 40, 0, 16), 0, 0));
		this.getContentPane().add(titlePanel,         new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0
			,GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(8, 8, 0, 8), 0, 0));
		titlePanel.add(titleLabel,        new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
			,GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE, new Insets(0, 4, 0, 0), 0, 0));
		titlePanel.add(jPanel1,    new GridBagConstraints(0, 1, 2, 1, 1.0, 0.0
			,GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 1));
		this.getContentPane().add(copyrightLabel,             new GridBagConstraints(0, 5, 1, 1, 1.0, 0.0
			,GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(4, 8, 4, 8), 0, 0));
		this.getContentPane().add(okayButton,             new GridBagConstraints(0, 4, 1, 1, 0.0, 1.0
			,GridBagConstraints.SOUTH, GridBagConstraints.NONE, new Insets(0, 4, 4, 4), 0, 0));
		this.getContentPane().add(versionLabel,       new GridBagConstraints(0, 1, 1, 1, 1.0, 0.0
			,GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(0, 8, 0, 8), 0, 0));
		this.getContentPane().add(urlLabel,     new GridBagConstraints(0, 3, 1, 1, 0.0, 0.0
			,GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(0, 40, 0, 16), 0, 0));
	}
}