/*
 * JDU: Disk Usage
 * 
 * Copyright (c) 2001-2005 Jason Pratt
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package org.jasonpratt.jdu;

/**
 * @author Jason Pratt
 */
public class Directory extends File {
	protected java.util.Comparator fileComparator = new java.util.Comparator() {
		public int compare( Object o1, Object o2 ) {
			if( (o1 instanceof File) && (o2 instanceof File) ) {
				long size1 = ((File)o1).getSize();
				long size2 = ((File)o2).getSize();
				if( size1 < size2 ) {
					return 1;
				} else if( size1 > size2 ) {
					return -1;
				} else {
					return 0;
				}
			}

			return 0; // if it's not a File, don't bother
		}
	};
	protected java.util.TreeSet subDirectories = new java.util.TreeSet( fileComparator );
	protected java.util.TreeSet files = new java.util.TreeSet( fileComparator );

	public Directory( Directory parent, java.io.File dir, ProgressObserver progressObserver ) {
		super( parent, dir );
		refresh( progressObserver );
	}

	public java.util.Set getSubDirectories() {
		return subDirectories;
	}

	public java.util.Set getFiles() {
		return files;
	}

	synchronized public void refresh( ProgressObserver progressObserver ) {
		if( (progressObserver != null) && progressObserver.needsUpdate() ) {
			progressObserver.updateCurrentItem( getFile().getAbsolutePath() );
		}

		java.io.File dir = getFile();
		subDirectories.clear();
		files.clear();

		java.io.File[] children = dir.listFiles();
		if( children != null ) {
			for( int i = 0; i < children.length; i++ ) {
				if( children[i].isDirectory() ) {
					subDirectories.add( new Directory( this, children[i], progressObserver ) );
				} else if( children[i].isFile() ) {
					files.add( new File( this, children[i] ) );
				} else {
					System.err.println( "Not a directory or a file: " + children[i].getAbsolutePath() );
				}
			}
		}

		if( (progressObserver != null) && progressObserver.needsUpdate() ) {
			progressObserver.updateCurrentItem( getFile().getAbsolutePath() );
		}
		calculateSize();
	}

	public void calculateSize() {
		size = 0;
		for( java.util.Iterator iter = subDirectories.iterator(); iter.hasNext(); ) {
			Directory d = (Directory)iter.next();
			size += d.getSize();
		}
		for( java.util.Iterator iter = files.iterator(); iter.hasNext(); ) {
			File f = (File)iter.next();
			size += f.getSize();
		}
	}
}