/*
 * JDU: Disk Usage
 * 
 * Copyright (c) 2001-2005 Jason Pratt
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package org.jasonpratt.jdu;

/**
 * @author Jason Pratt
 */
public class File {
	protected Directory parent;
	protected java.io.File file;
	protected String name;
	protected long size = -1;
	protected String sizeString;
	protected java.text.DecimalFormat sizeFormatter = new java.text.DecimalFormat( "#0.00" );

	public File( Directory parent, java.io.File file ) {
		this.parent = parent;
		this.file = file;
		if( file != null ) {
			this.name = file.getName();
			this.size = file.length();
		}
	}

	public Directory getParent() {
		return parent;
	}

	public java.io.File getFile() {
		return file;
	}

	public String getName() {
		if( name == null ) { // delayed lookup
			name = file.getName();
		}
		return name;
	}

	public long getSize() {
		if( size == -1 ) { // delayed lookup
			size = file.length();
		}
		return size;
	}

	public String getSizeString() {
		if( sizeString == null ) { // create on demand
			getSize(); // ensure size is up-to-date
			if( size < 1024 ) {
				sizeString = sizeFormatter.format( size ) + " bytes";
			} else if( size < 1024L*1024L ) {
				sizeString = sizeFormatter.format( ((double)size)/((double)1024) ) + " KB";
			} else if( size < 1024L*1024L*1024L ) {
				sizeString = sizeFormatter.format( ((double)size)/((double)1024L*1024L) ) + " MB";
			} else if( size < 1024L*1024L*1024L*1024L ) {
				sizeString = sizeFormatter.format( ((double)size)/((double)1024L*1024L*1024L) ) + " GB";
			} else {
				sizeString = sizeFormatter.format( ((double)size)/((double)1024L*1024L*1024L*1024L) ) + " TB";
			}
		}

		return sizeString;
	}

	public boolean equals( Object o ) {
		if( o instanceof File ) {
			return ((File)o).getFile().equals( file );
		} else {
			return file.equals( o );
		}
	}

	public String toString() {
		if( file == null ) {
			return "null";
		} else {
			return file.getAbsolutePath();
		}
	}
}