/*
 * JDU: Disk Usage
 * 
 * Copyright (c) 2001-2005 Jason Pratt
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package org.jasonpratt.jdu;

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

/**
 * @author Jason Pratt
 */
public class GettingStartedDialog extends javax.swing.JDialog {
	private static final long serialVersionUID = -362834966779750856L;
	javax.swing.event.HyperlinkListener hyperlinkListener = new javax.swing.event.HyperlinkListener() {
		public void hyperlinkUpdate( javax.swing.event.HyperlinkEvent ev ) {
			if( ev.getEventType() == javax.swing.event.HyperlinkEvent.EventType.ACTIVATED ) {
				try {
					JDUFrame.openURL( ev.getURL().toExternalForm() );
				} catch( Throwable t ) {
					System.err.println( "Couldn't load the URL;  " + t.getMessage() );
				}
			}
		}
	};

	public GettingStartedDialog( java.awt.Frame owner ) {
		super( owner );
		jbInit();
		guiInit();
	}

	private void guiInit() {
		setTitle( "Getting Started" );
		setSize( 610, 500 );
		JDUFrame.centerComponentOnScreen( this );
		try {
			editorPane.setPage( GettingStartedDialog.class.getResource( "html/gettingStarted.html" ) );
		} catch( java.io.IOException e ) {
			e.printStackTrace();
		}

		editorPane.addHyperlinkListener( hyperlinkListener );
	}

	//////////////
	// Callbacks
	//////////////

	void doneButton_actionPerformed(ActionEvent e) {
		setVisible( false );
	}

	//////////////////
	// Autogenerated
	//////////////////

	JScrollPane scrollPane = new JScrollPane();
	JEditorPane editorPane = new JEditorPane();
	JButton doneButton = new JButton();
	GridBagLayout gridBagLayout1 = new GridBagLayout();

	private void jbInit() {
		this.getContentPane().setLayout(gridBagLayout1);
		editorPane.setToolTipText("");
		editorPane.setEditable(false);
		editorPane.setMargin(new Insets(10, 10, 10, 10));
		doneButton.setText("Done");
		doneButton.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(ActionEvent e) {
				doneButton_actionPerformed(e);
			}
		});
		this.getContentPane().add(scrollPane,   new GridBagConstraints(0, 0, 1, 1, 1.0, 1.0
			,GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
		this.getContentPane().add(doneButton,   new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0
			,GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(4, 0, 4, 0), 0, 0));
		scrollPane.getViewport().add(editorPane, null);
	}
}